from setuptools import setup

if __name__ == "__main__":
    setup(
        install_requires=[],
        extras_require={
            "dist": ["wheel", "twine", "bump2version"],
            "docs": [
                "sphinx",
                "pyimport",
                "pypandoc",
                "sphinxcontrib.apidoc",
                "sphinxcontrib.pandoc_markdown",
                "sphinx-autodoc-annotation",
                "yummy_sphinx_theme",
            ],
            "tests": [
                "pytest",
                "pytest-cov",
                "pytest-html",
                "pytest-sugar",
                "pytest-bdd",
                "pytest-watch",
            ],
        },
    )



import os
from typing import Any

from .exceptions import InvalidEnvVar, MissingEnvVar


def from_env(name: str) -> Any:
    if name not in os.environ:
        raise MissingEnvVar(name)

    value = os.environ.get(name)
    if value == None:
        raise InvalidEnvVar(name)

    return value



class MissingEnvVar(Exception):
    def __init__(self, env_var_name: str) -> None:
        super().__init__(f"The environment variable '{env_var_name}' is not set")


class InvalidEnvVar(Exception):
    def __init__(self, env_var_name: str) -> None:
        super().__init__(f"The environment variable '{env_var_name}' is empty or None")
